/**
 * GenesisServerError.
 * @remarks
 * Represents an error received from a Genesis Server.
 * @public
 */
export class GenesisServerError extends Error {
    constructor(sent, received, message = 'Genesis Server Error Occurred') {
        super(message);
        this.sent = sent;
        this.received = received;
        this.name = 'GenesisServerError';
        Object.setPrototypeOf(this, GenesisServerError.prototype);
    }
    /**
     * Capture known edge cases.
     * @privateRemarks
     * This is ugly, lets figure out if this is still an issue and remove if not.
     */
    isIgnorableError() {
        if (this.received?.DETAILS?.ERROR?.toLowerCase()?.includes('request needs the user to be logged')) {
            return true;
        }
        return false;
    }
    getMessageError() {
        return Array.isArray(this.received?.ERROR)
            ? this.received?.ERROR.map((error) => this.errorDetailFormatter(error)).join('\n')
            : '';
    }
    getDetailsError() {
        return Array.isArray(this.received?.DETAILS?.ERROR)
            ? this.received?.DETAILS?.ERROR.map((error) => this.errorDetailFormatter(error)).join('\n')
            : '';
    }
    hasErrorCode(code) {
        return Array.isArray(this.received?.ERROR)
            ? this.received?.ERROR.some((error) => error.CODE === code)
            : false;
    }
    errorDetailFormatter(error) {
        return `\n ${error.CODE}: \n ${error.TEXT}`;
    }
}
/**
 * @param error - An error.
 * @public
 */
export const isGenesisServerError = (error) => error instanceof GenesisServerError;
/**
 * MappingError.
 * @public
 */
export class MappingError extends Error {
    constructor(dto, message = 'Mapping Error Occurred') {
        super(message);
        this.dto = dto;
        this.name = 'MappingError';
        Object.setPrototypeOf(this, MappingError.prototype);
    }
}
/**
 * @param error - An error.
 * @public
 */
export const isMappingError = (error) => error instanceof MappingError;
