import { JSONReviver } from '@genesislcap/foundation-utils';
import { defaultFetchPolicy } from './policies';
/**
 * {@inheritDoc ResponseOkChecker}
 * @public
 */
export const defaultResponseOkChecker = (response) => response.ok;
/**
 * {@inheritDoc ResponseDataExtractor}
 * @public
 */
export const defaultResponseDataExtractor = async (response) => {
    const text = await response.text();
    const contentType = response.headers.get('content-type');
    const expectingJson = contentType?.includes('application/json');
    return expectingJson ? JSON.parse(text, JSONReviver) : text;
};
/**
 * Creates an extractor that applies a deserializer to the extracted response data.
 * @param deserializer - The deserializer to apply.
 * @param extractor - An optional data extractor. Defaults to {@link defaultResponseDataExtractor}.
 * @public
 */
export const createResponseDataExtractorWithDeserializer = (deserializer, extractor = defaultResponseDataExtractor) => async (response) => {
    const json = await extractor(response);
    return deserializer(json);
};
/**
 * The default fetch config.
 * @public
 */
export const defaultFetchConfig = {
    fetcher: fetch,
    fetchPolicy: defaultFetchPolicy,
    responseOkChecker: defaultResponseOkChecker,
    responseDataExtractor: defaultResponseDataExtractor,
};
/**
 * Default FetchMachineContext.
 * @public
 */
export const defaultFetchMachineContext = {
    params: undefined,
    controller: undefined,
    response: undefined,
    data: undefined,
};
